@@ -164,7 +164,8 @@ class ObjectConfig:
 		self.type = configNode.getAttribute('type')
 		self.gad = configNode.getAttribute('gad')
 		self.callback = configNode.getAttribute('pyknxcallback')
-		self.init = configNode.getAttribute('init')
+		self.init = configNode.getAttribute('init') if configNode.hasAttribute('init') else 'request'
+		self.flags = configNode.getAttribute('flags') if configNode.hasAttribute('flags') else 'cwtu'
 		firstTypeDigit = self.type[0:self.type.find('.')]
 		if firstTypeDigit == '1':
 			self.typeCategory = 'bool'
